@@ -6,7 +6,7 @@
  * Date        : 2006-09-15
  * Description : Exiv2 library interface for KDE
  *
- * Copyright (C) 2006-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2008 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2006-2007 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
  * NOTE: Do not use kdDebug() in this implementation because 
@@ -77,6 +77,7 @@
 
 // Local includes.
 
+#include "version.h"
 #include "kexiv2.h"
 
 namespace KExiv2Iface
@@ -95,6 +96,7 @@ public:
     Exiv2::ExifData exifMetadata;
 
     Exiv2::IptcData iptcMetadata;
+
 };
 
 KExiv2::KExiv2()
@@ -113,6 +115,11 @@ KExiv2::~KExiv2()
     delete d;
 }
 
+QString KExiv2::version()
+{
+  return QString( kexiv2_version );
+}
+
 QString KExiv2::Exiv2Version()
 {
     // Since 0.14.0 release, we can extract run-time version of Exiv2.
@@ -120,7 +127,7 @@ QString KExiv2::Exiv2Version()
 
 #if (EXIV2_TEST_VERSION(0,14,0))
     return QString(Exiv2::version());
-#else	   
+#else
     return QString("%1.%2.%3").arg(EXIV2_MAJOR_VERSION)
                               .arg(EXIV2_MINOR_VERSION)
                               .arg(EXIV2_PATCH_VERSION);
@@ -130,7 +137,7 @@ QString KExiv2::Exiv2Version()
 void KExiv2::printExiv2ExceptionError(const QString& msg, Exiv2::Error& e)
 {
     std::string s(e.what());
-    qDebug("%s (%s)", msg.ascii(), s.c_str());
+    qDebug("%s (Error #%i: %s)", msg.ascii(), e.code(), s.c_str());
 }
 
 std::string& KExiv2::commentsMetaData()
@@ -156,7 +163,7 @@ bool KExiv2::clearComments()
 bool KExiv2::clearExif()
 {
     try
-    {    
+    {
         d->exifMetadata.clear();
         return true;
     }
@@ -1131,7 +1138,7 @@ bool KExiv2::setImagePreview(const QImage& preview, bool setProgramName)
         if ( !file.open(IO_ReadOnly) ) 
             return false;
 
-        qDebug("(%i x %i) JPEG image preview size: %i bytes", 
+        qDebug("JPEG image preview size: (%i x %i) pixels - %i bytes", 
                preview.width(), preview.height(), (int)file.size());
         
         QByteArray data(file.size());
@@ -1785,13 +1792,14 @@ bool KExiv2::setGPSInfo(double altitude, double latitude, double longitude, bool
         // Now start adding data.
 
         // ALTITUDE.
-        // Altitude reference: byte "00" meaning "sea level".
+        // Altitude reference: byte "00" meaning "above sea level", "01" mening "behing sea level".
         value = Exiv2::Value::create(Exiv2::unsignedByte);
-        value->read("0");
+	if (altitude >= 0) value->read("0");
+	else               value->read("1");
         d->exifMetadata.add(Exiv2::ExifKey("Exif.GPSInfo.GPSAltitudeRef"), value.get());
         
-        // And the actual altitude.
-        convertToRational(altitude, &nom, &denom, 4);
+        // And the actual altitude, as absolute value.
+        convertToRational(fabs(altitude), &nom, &denom, 4);
         snprintf(scratchBuf, 100, "%ld/%ld", nom, denom);
         d->exifMetadata["Exif.GPSInfo.GPSAltitude"] = scratchBuf;
 
